==> vn-is-1.0.0.tgz: package/index.js <==
function trim(str){
	return str.replace(/^\s+/, "").replace(/\s+$/, "").replace(/\s+/g, " ");
};
function empty(s){
    if(!s) return true;
	return !(s.length||Object.keys(s).length);
};
module.exports = {
	_error: {},
	error: 0,
	start: function(){
		this.error = 0;
	},
	set: function(key, type){
		this._error[key] = type ? lang.error[key][type] : lang.error[key];
		return false;
	},
	get: function(key){
		this.error++;
		return this._error[key];
	},
	id: function(value){
		switch(typeof value){
			case 'number': return true;
			case 'string': return /^[0-9]{1,15}$/.test(value);
			default: return false;
		}
	},
	name: function (n){
		var type, name = trim(n||''), count = name.length;
		/* check length */
		if(count<2) type = 'short';
		else if(count>30) type = 'long';
		else{
			/* word count */
			if(name.split(' ').length>2) type = 'many_word';
			else{
				/* ki tu dac biet */
				var reg = /[~`!@#\$%\^&\*\(\)_\+\-=\{\}\[\]\\:\';\'<>\?\,\.\/\|\d]+/g;
				if(reg.test(name)) type = 'not_valid';
				else{
					/* ki tu in hoa */
					var locale_upper_case = name.match(/[QWERTYUIOPASDFGHJKLZXCVBNMƯỨỮỬỰAĂÂÁÀẢÃẠĂẮẰẶẴẲẤẦẨẪẬĐÊẾỀỂỄỆÍÌỈĨỊÝỲỶỸỴ]/g);
					if(locale_upper_case&&locale_upper_case.length>2) type = 'many_upper';
					else return true;
				}
			}
		};
		return this.set('name', type);
	},
	gender: function(gender){
		return (gender==='male'||gender==='female') ? true : this.set('gender');
	},
	birthday: function(day, month, year){
		var d = Number(day), m = Number(month), y = Number(year), message = null;
		if(isNaN(d)||isNaN(m)||isNaN(y)) message = 'not_valid';
		else if(d<0||m<1||y<1960||d>31||m>12||y>2015) message = 'not_valid';
		else if((d===30||d===31)&&m===2) message = 'leap_year';
		else return true;
		return this.set('birthday', message);
	},
	phone: function (phone) {
		return (/^[0-9]{9,15}$/g.test(phone)&&/^(0|\+)/.test(phone[0])) ? true : this.set('email', 'input');
	},
	code: function (a) {
		return /^[0-9]{5}$/g.test(a) ? true : this.set('confirm', 'syntax');
	},
	pass: function (a) {
		return /(.){8,100}/g.test(a) ? true : this.set('pass', 'syntax');
	},
	email: function (a) {
		var filter = /^([a-zA-Z0-9_\.\-])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/g;
		return filter.test(a) ? true : this.set('email', 'input');
	},
	username: function (a) {
		return /^[a-zA-Z0-9\.]{1,50}$/gi.test(a) ? true : this.set('email', 'input');
	},
	url: function (a) {
		var urlRegex = /(http|https|ftp)\:\/\/([a-zA-Z0-9\.\-]+(\:[a-zA-Z0-9\.&amp;%\$\-]+)*@)*((25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9])\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9]|0)\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9]|0)\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[0-9])|([a-zA-Z0-9\-]+\.)*[a-zA-Z0-9\-]+\.(com|edu|gov|int|mil|net|org|biz|arpa|info|name|pro|aero|coop|museum|[a-zA-Z]{2}))(\:[0-9]+)*(\/($|[a-zA-Z0-9\.\,\?\'\\\+&amp;%\$#\=~_\-]+))*/g;
		var url = urlRegex.exec(a);
		if (url && url.length) { return url[0]; } else { return false; }
	},
	image: function (fileType) {
		var p = fileType.split('/');
		switch(p[0]){
			case 'image': return (/^(bmp|gif|jpeg|jpg|png)$/.test(p[1]))?p[1]:false;
		}
	}
};

==> vn-is-1.0.1.tgz: package/index.js <==
function trim(str){
	return str.replace(/^\s+/, "").replace(/\s+$/, "").replace(/\s+/g, " ");
};
function empty(s){
    if(!s) return true;
	return !(s.length||Object.keys(s).length);
};
module.exports = {
	_error: {},
	error: 0,
	start: function(){
		this.error = 0;
	},
	set: function(key){
		this._error[key] = lang[key];
		return false;
	},
	get: function(key){
		this.error++;
		return this._error[key];
	},
	id: function(value){
		switch(typeof value){
			case 'number': return true;
			case 'string': return (/^[0-9]{1,15}$/.test(value)&&value[0]!=="0");
			default: return false;
		}
	},
	name: function (n){
		var type, name = trim(n||''), count = name.length;
		/* check length */
		if(count<2) type = 'error_name_short';
		else if(count>30) type = 'error_name_long';
		else{
			/* word count */
			if(name.split(' ').length>2) type = 'error_name_many_word';
			else{
				/* ki tu dac biet */
				var reg = /[~`!@#\$%\^&\*\(\)_\+\-=\{\}\[\]\\:\';\'<>\?\,\.\/\|\d]+/g;
				if(reg.test(name)) type = 'error_name_not_valid';
				else{
					/* ki tu in hoa */
					var locale_upper_case = name.match(/[QWERTYUIOPASDFGHJKLZXCVBNMƯỨỮỬỰAĂÂÁÀẢÃẠĂẮẰẶẴẲẤẦẨẪẬĐÊẾỀỂỄỆÍÌỈĨỊÝỲỶỸỴ]/g);
					if(locale_upper_case&&locale_upper_case.length>2) type = 'error_name_many_upper';
					else return true;
				}
			}
		};
		return this.set(type);
	},
	gender: function(gender){
		return (gender==='male'||gender==='female') ? true : this.set('error_gender');
	},
	birthday: function(day, month, year){
		var d = Number(day), m = Number(month), y = Number(year), message = null;
		if(isNaN(d)||isNaN(m)||isNaN(y)) message = 'error_birthday_not_valid';
		else if(d<0||m<1||y<1960||d>31||m>12||y>2015) message = 'error_birthday_not_valid';
		else if((d===30||d===31)&&m===2) message = 'error_birthday_leap_year';
		else return true;
		return this.set(message);
	},
	phone: function (phone) {
		return (/^[0-9]{9,15}$/g.test(phone)&&/^(0|\+)/.test(phone[0])) ? true : this.set('error_email_input');
	},
	code: function (a) {
		return /^[0-9]{5}$/g.test(a) ? true : this.set('error_confirm_not_valid');
	},
	pass: function (a) {
		return /(.){8,100}/g.test(a) ? true : this.set('error_pass_not_valid');
	},
	email: function (a) {
		var filter = /^([a-zA-Z0-9_\.\-])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/g;
		return filter.test(a) ? true : this.set('error_email_input');
	},
	username: function (a) {
		return /^[a-zA-Z0-9\.]{1,50}$/gi.test(a) ? true : this.set('error_email_input');
	},
	url: function (a) {
		var urlRegex = /(http|https|ftp)\:\/\/([a-zA-Z0-9\.\-]+(\:[a-zA-Z0-9\.&amp;%\$\-]+)*@)*((25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9])\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9]|0)\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[1-9]|0)\.(25[0-5]|2[0-4][0-9]|[0-1]{1}[0-9]{2}|[1-9]{1}[0-9]{1}|[0-9])|([a-zA-Z0-9\-]+\.)*[a-zA-Z0-9\-]+\.(com|edu|gov|int|mil|net|org|biz|arpa|info|name|pro|aero|coop|museum|[a-zA-Z]{2}))(\:[0-9]+)*(\/($|[a-zA-Z0-9\.\,\?\'\\\+&amp;%\$#\=~_\-]+))*/g;
		var url = urlRegex.exec(a);
		if (url && url.length) { return url[0]; } else { return false; }
	},
	image: function (fileType) {
		var p = fileType.split('/');
		switch(p[0]){
			case 'image': return (/^(bmp|gif|jpeg|jpg|png)$/.test(p[1]))?p[1]:false;
		}
	}
};
